@@ -1,17 +1,21 @@
-#line 1 "inc/Module/Install/Scripts.pm - /opt/lib/perl5/site_perl/5.8.3/Module/Install/Scripts.pm"
-# $File: //depot/cpan/Module-Install/lib/Module/Install/Scripts.pm $ $Author: autrijus $
-# $Revision: #7 $ $Change: 1841 $ $DateTime: 2003/12/28 19:43:56 $ vim: expandtab shiftwidth=4
-
+#line 1
 package Module::Install::Scripts;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
-$VERSION = '0.01';
+
 use strict;
+use Module::Install::Base;
 use File::Basename ();
 
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+	$VERSION = '0.65';
+	$ISCORE  = 1;
+	@ISA     = qw{Module::Install::Base};
+}
+
 sub prompt_script {
     my ($self, $script_file) = @_;
-    my ($prompt, $abstract, $default);
 
+    my ($prompt, $abstract, $default);
     foreach my $line ( $self->_read_script($script_file) ) {
         last unless $line =~ /^#/;
         $prompt = $1   if $line =~ /^#\s*prompt:\s+(.*)/;
@@ -29,10 +33,10 @@ sub prompt_script {
 }
 
 sub install_script {
-    my ($self, $script_file) = @_;
+    my $self = shift;
     my $args = $self->makemaker_args;
     my $exe_files = $args->{EXE_FILES} ||= [];
-    push @$exe_files, $script_file;
+    push @$exe_files, @_;
 }
 
 sub _read_script {
